#!/usr/bin/env node --experimental-modules --no-warnings
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const meow_1 = __importDefault(require("meow"));
const get_stdin_1 = __importDefault(require("get-stdin"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const index_1 = __importDefault(require("./index"));
const log_1 = __importDefault(require("./lib/log"));
const result_type_1 = __importDefault(require("./lib/types/result-type"));
const helpText = fs_1.default.readFileSync(path_1.default.join(__dirname, '..', 'usage.txt'), { encoding: 'utf8' });
const cli = meow_1.default(helpText, {
    description: 'Validate commit messages against the seven rules of commit messages.',
    flags: {
        silent: { type: 'boolean', alias: 's' },
        verbose: { type: 'boolean', alias: 'v' },
        file: { type: 'string', alias: 'f' },
        help: { type: 'boolean', alias: 'h' }
    }
});
if (cli.flags.silent && cli.flags.verbose) {
    cli.showHelp();
}
let commitMessage;
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        if (cli.flags.file !== undefined) {
            commitMessage = fs_1.default.readFileSync(cli.flags.file, { encoding: 'utf8' });
        }
        else if (cli.input.length > 0) {
            [commitMessage] = cli.input;
        }
        else {
            commitMessage = (yield get_stdin_1.default()) || process.exit(0);
        }
        if (!cli.flags.silent) {
            log_1.default(); // Leading new line
        }
        const results = index_1.default(commitMessage);
        let exitCode = 0;
        for (const result of results) {
            switch (result.type) {
                case result_type_1.default.fail:
                    if (!cli.flags.silent) {
                        log_1.default.error(result.rule.message);
                    }
                    exitCode = 1;
                    break;
                case result_type_1.default.pass:
                    if (!cli.flags.silent && cli.flags.verbose) {
                        log_1.default.success(result.rule.message);
                    }
                    break;
                case result_type_1.default.info:
                    if (!cli.flags.silent && cli.flags.verbose) {
                        log_1.default.info(result.rule.message);
                    }
                    break;
                default:
                    throw new Error(`Internal Error: Invalid result type '${result.type}'`);
            }
        }
        process.exit(exitCode);
    });
}
main();
