"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_body_1 = __importDefault(require("./util/get-body"));
const get_subject_line_1 = __importDefault(require("./util/get-subject-line"));
const is_lower_case_1 = __importDefault(require("./util/is-lower-case"));
const one = {
    message: 'Separate subject from body with a blank line',
    test: (commitMessage) => {
        const separatedByLf = /^.+(\n\n(?:.|\n)+|\n?)$/g;
        return separatedByLf.test(commitMessage);
    }
};
const two = {
    message: 'Limit the subject line to 50 characters',
    test: (commitMessage) => {
        const subjectLine = get_subject_line_1.default(commitMessage);
        const cutOff = 50;
        return subjectLine.length < cutOff;
    }
};
const three = {
    message: 'Capitalize the subject line',
    test: (commitMessage) => {
        const subjectLine = get_subject_line_1.default(commitMessage);
        const firstCharacter = subjectLine[0];
        return !is_lower_case_1.default(firstCharacter);
    }
};
const four = {
    message: 'Do not end the subject line with a period',
    test: (commitMessage) => {
        const subjectLine = get_subject_line_1.default(commitMessage);
        const lastCharacter = subjectLine.substr(-1);
        return !(lastCharacter === '.');
    }
};
const five = {
    message: 'Use the imperative mood in the subject line'
    // We could, in theory, use NLP to check for this rule,
    // ...but it would take effort and would be error prone
};
const six = {
    message: 'Wrap the body at 72 characters',
    test: (commitMessage) => {
        const bodyLines = get_body_1.default(commitMessage).split('\n');
        return bodyLines.every(line => line.length < 72);
    }
};
const seven = {
    message: 'Use the body to explain _what_ and _why_ vs. _how_'
    // This is obviously not detectable programtically
};
const rules = [
    one, two, three, four, five, six, seven
];
exports.default = rules;
